@@ -19,15 +19,14 @@ if(xsystem("which cdclconfig"))
   ldflags = `cdclconfig --ldflags`.gsub(/\n/, " ")
   ldlibs = `cdclconfig --ldlibs`.gsub(/-R.*?\s/, " ").gsub(/\n/, " ")
   print "checking DCL version... "
-  dclversion = `cdclconfig --dclversion`[0..2]
-  print dclversion,"\n"
-  case dclversion
-  when "5.2","5.3"
-    # ok
-  else
-    raise "unsupported DCL version"
+  dclversion = `cdclconfig --dclversion`.strip
+  print "DCL Version: #{dclversion}\n"
+  dclver = dclversion.sub(/\./,'')
+  dclver = dclver+'0' if dclver.length <= 2   # 53 --> 530 etc
+  if dclversion < "5.2"
+    raise "Supported DCL version is 5.2 or later, while you have #{dclversion}"
   end
-  dclversionmacro = ' -DDCLVER='+dclversion.sub(/\./,'')  # -DDCL52 etc
+  dclversionmacro = ' -DDCLVER='+dclver
 
   $CFLAGS += ' '+cflags  + dclversionmacro
   $LOCAL_LIBS += ' ' + ldflags
@@ -47,16 +46,22 @@ if(xsystem("which cdclconfig"))
     end
   end
   if gtkversion == "no" then
-    File.copy("init.c.default","init.c")
+    initcfile = "init.c.default"
   else
     print "**Infomation** compile with gtk+ (ver.#{gtkversion})\n"
     File.copy("grph1_zgpack.c.org","grph1_zgpack.c")
-    File.safe_unlink("init.c")
-    File.copy("init.c.gtk","init.c")
+    initcfile = "init.c.gtk"
     if ldlibs =~ /-lgdk_imlib/ then
       print "**Infomation** compile with imlib_gdk\n"
     end
   end
+  fin = File.open(initcfile)
+  fout = File.open('init.c','w')
+  while(line = fin.gets)
+    fout.puts(line.sub(/DCLVersion/,'"'+dclversion+'"'))
+  end
+  fout.close
+  fin.close
 
 else
   print "**Warning** cdclconfig is not found. Assume C version of DCL 5.2\n"
